News for hackers. Stuff that matters.
Re:My Journey from R to Julia by npalli on Sunday January 29, 2023 @10:26AM (#34568918)
Sorry, not following the logic here. From the article, vectorization[1] is more than 10 times faster than a loop. How is this an endorsement for "for" loops.

   [1] Vectorization is more than ten times faster than the naive loop.

There are no comments on this comment yet.